pub struct DeploymentManifestBuilder { /* private fields */ }Expand description
Builder that validates a deployment only after all providers are selected.
Implementations
Sourceimpl DeploymentManifestBuilder
impl DeploymentManifestBuilder
Sourcepub fn new(
installation_id: InstallationId,
application_id: ApplicationId,
mode: RuntimeMode,
storage: ProviderConfig,
network: NetworkConfig,
) -> Self
pub fn new( installation_id: InstallationId, application_id: ApplicationId, mode: RuntimeMode, storage: ProviderConfig, network: NetworkConfig, ) -> Self
Starts a deployment with required installation, storage and network choices.
Sourcepub fn with_control_plane(self, provider: ProviderConfig) -> Self
pub fn with_control_plane(self, provider: ProviderConfig) -> Self
Selects the cluster control-plane provider.
Sourcepub fn with_supervisor(self, supervisor: DeploymentSupervisorConfig) -> Self
pub fn with_supervisor(self, supervisor: DeploymentSupervisorConfig) -> Self
Replaces installation-owned supervisor settings.
Sourcepub fn with_coordination_store(self, provider: ProviderConfig) -> Self
pub fn with_coordination_store(self, provider: ProviderConfig) -> Self
Selects an optional coordination-store provider.
Sourcepub fn with_secret_provider(self, provider: ProviderConfig) -> Self
pub fn with_secret_provider(self, provider: ProviderConfig) -> Self
Selects the provider that resolves installation secret references.
Sourcepub fn with_job_provider(self, provider: ProviderConfig) -> Self
pub fn with_job_provider(self, provider: ProviderConfig) -> Self
Selects an optional durable job provider.
Sourcepub fn with_secret(
self,
name: impl Into<String>,
secret: SecretRef,
) -> ContractResult<Self>
pub fn with_secret( self, name: impl Into<String>, secret: SecretRef, ) -> ContractResult<Self>
Adds an installation-level secret reference.
Sourcepub fn with_path(
self,
name: impl Into<String>,
path: impl Into<String>,
) -> ContractResult<Self>
pub fn with_path( self, name: impl Into<String>, path: impl Into<String>, ) -> ContractResult<Self>
Adds a named installation path.
Sourcepub fn with_volume(self, volume: VolumeMount) -> Self
pub fn with_volume(self, volume: VolumeMount) -> Self
Adds a volume mount.
Sourcepub fn with_database(self, provider: ProviderConfig) -> Self
pub fn with_database(self, provider: ProviderConfig) -> Self
Selects an optional application database provider.
Sourcepub fn with_update_provider(self, provider: ProviderConfig) -> Self
pub fn with_update_provider(self, provider: ProviderConfig) -> Self
Selects an optional update provider.
Sourcepub fn with_peer_discovery(self, provider: ProviderConfig) -> Self
pub fn with_peer_discovery(self, provider: ProviderConfig) -> Self
Selects the cluster peer-discovery provider.
Sourcepub fn with_adapter(
self,
name: impl Into<String>,
provider: ProviderConfig,
) -> ContractResult<Self>
pub fn with_adapter( self, name: impl Into<String>, provider: ProviderConfig, ) -> ContractResult<Self>
Adds a named provider adapter.
Sourcepub fn with_environment_literal(
self,
name: impl Into<String>,
value: impl Into<String>,
) -> ContractResult<Self>
pub fn with_environment_literal( self, name: impl Into<String>, value: impl Into<String>, ) -> ContractResult<Self>
Adds a non-sensitive environment literal.
Sourcepub fn with_environment_secret(
self,
name: impl Into<String>,
secret: SecretRef,
) -> ContractResult<Self>
pub fn with_environment_secret( self, name: impl Into<String>, secret: SecretRef, ) -> ContractResult<Self>
Adds an environment variable backed by a secret reference.
Sourcepub fn build(self) -> ContractResult<DeploymentManifestV1>
pub fn build(self) -> ContractResult<DeploymentManifestV1>
Builds and validates the deployment contract.